<?xml version="1.0" encoding="ISO-8859-1"?>
 
<xsl:stylesheet version="1.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:gdv="http://www.gdv.de/2003/GdvmlSchema/Antrag/Leben">

 <!-- Dieses Stylesheet erzeugt die XML-Schema-Definition fr GdvmlAntragLeben
      mit spezifischen Ergnzungen fr die Produktspezifischen Stammdaten einer Schlsselpflegenden Stelle
 
				<schema 
					xmlns="http://www.w3.org/2001/XMLSchema"
					targetNamespace="http://www.gdv.de/2003/GdvmlSchema/Antrag/Leben"
					xmlns:gdv="http://www.gdv.de/2003/GdvmlSchema/Antrag/Leben"
					version="1.0.0"
					elementFormDefault="qualified">

          ...
          
        </schema>
      -->

 <xsl:output method="xml" encoding="ISO-8859-1" standalone="yes" indent="yes"/>

 <xsl:key name="satzart" match="satzart" use="@referenz"/>
   
 <xsl:template match="/">
  <xsl:comment>
    GdvmlAntragLeben
    ****************
    
    ****************************************************************************
    * Diese Datei ist aus den produktspezifischen Stammdaten generiert worden. *
    ****************************************************************************
    
    Sie enthlt die XML-Schema-Definition fr die produktspezifischen Felder von GdvmlAntragLeben

  </xsl:comment>
  
  <xsl:apply-templates select="gdv:ProduktspezifischeStammdaten/gdv:Liste[position() = last()]"/>   
 </xsl:template>

 <xsl:template match="gdv:Liste">
  <schema 
 	 xmlns="http://www.w3.org/2001/XMLSchema"
	 xmlns:gdv="http://www.gdv.de/2003/GdvmlSchema/Antrag/Leben"
	 version="1.0.0"
	 elementFormDefault="qualified">
   <xsl:attribute name="targetNamespace"><xsl:value-of select="gdv:ProduktspezifischeListeStammdaten/gdv:ListenID"/></xsl:attribute>

   <import namespace="http://www.gdv.de/2003/GdvmlSchema/Antrag/Leben" schemaLocation="GdvmlAntragLeben.xsd"/>
     
   <xsl:comment>
   
    Die Struktur der produktspezifischen Felder
    *******************************************
    
    Fr jedes produktspezifische Feld wird ein xsd:element definiert
   </xsl:comment>
   <xsl:apply-templates select="gdv:Felder/gdv:ProduktspezifischesFeldStammdaten[gdv:Bezugsfeldart = '0']"/>

  </schema>
 </xsl:template>

 <xsl:template match="gdv:ProduktspezifischesFeldStammdaten[gdv:Bezugsfeldart = '0']">
  <!--element maxOccurs="1"-->
  <element>
   <xsl:attribute name="name"><xsl:value-of select="gdv:FeldID"/></xsl:attribute>
   <!--xsl:attribute name="minOccurs">
    <xsl:choose>
     <xsl:when test="gdv:Optionalitaet = '0'">0</xsl:when>
     <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose> 
   </xsl:attribute-->
   <complexType>
    <sequence>
      <xsl:call-template name="PSF">
       <xsl:with-param name="feldID" select="gdv:FeldID"/>
      </xsl:call-template> 
    </sequence>
    <attribute name="feldidentifikationKlartext" type="gdv:ET-Text030-Type" use="optional">
         <xsl:attribute name="fixed"><xsl:value-of select="gdv:FeldidentifikationKlartext"/></xsl:attribute>
    </attribute>
    <attribute name="wert" use="required">
        <simpleType>
   	   <xsl:choose>
       <xsl:when test="gdv:Feldtyp = '010'">
        <restriction base="boolean">
         <pattern value="[01]"/>
        </restriction> 
       </xsl:when>
       <xsl:when test="gdv:Feldtyp = '020'">
        <restriction base="string">
         <pattern>
             <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:pattern/@gdv:value"/></xsl:attribute>
         </pattern>
        </restriction> 
       </xsl:when>
       <xsl:when test="gdv:Feldtyp = '030'">
        <restriction base="decimal">
         <totalDigits>
             <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:totalDigits/@value"/></xsl:attribute>
         </totalDigits>
         <fractionDigits>
             <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:fractionDigits/@value"/></xsl:attribute>
         </fractionDigits>
            <xsl:if test="gdv:Formatdefinition/gdv:minInclusive">
   	       <minInclusive>
              <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:minInclusive/@value"/></xsl:attribute>
          </minInclusive>
            </xsl:if>
            <xsl:if test="gdv:Formatdefinition/gdv:minExclusive">
   	       <minExclusive>
              <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:minExclusive/@value"/></xsl:attribute>
          </minExclusive>
            </xsl:if>
            <xsl:if test="gdv:Formatdefinition/gdv:maxInclusive">
   	       <maxInclusive>
              <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:maxInclusive/@value"/></xsl:attribute>
          </maxInclusive>
            </xsl:if>
            <xsl:if test="gdv:Formatdefinition/gdv:maxExclusive">
   	       <maxExclusive>
              <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:maxExclusive/@value"/></xsl:attribute>
          </maxExclusive>
            </xsl:if>
        </restriction> 
       </xsl:when>
       <xsl:when test="gdv:Feldtyp = '040'">
        <restriction base="string"/>
       </xsl:when>
       <xsl:when test="gdv:Feldtyp = '050'">
        <restriction base="string">
         <xsl:for-each select="gdv:Formatdefinition/gdv:enumeration">
             <enumeration>
              <xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
          </enumeration>
         </xsl:for-each>
        </restriction> 
       </xsl:when>
      </xsl:choose>
     </simpleType> 
    </attribute>
   </complexType>
  </element>
 </xsl:template> 

 <xsl:template name="PSF">
  <xsl:param name="feldID" select="/.."/>

  <xsl:for-each select="/gdv:ProduktspezifischeStammdaten/gdv:Liste/gdv:Felder/gdv:ProduktspezifischesFeldStammdaten[
                            gdv:Bezugsfeldart = '1' and gdv:BezugProduktspezifischesFeldIdentifikation = $feldID]">
   <!--xsl:message terminate="no">PSF: Hier kommt das PSF <xsl:value-of select="gdv:FeldID"/> in der Version <xsl:value-of select="gdv:Version"/> hin.</xsl:message-->
   <!--element name="ProduktspezifischesFeld" maxOccurs="1"-->
   <element maxOccurs="1">
    <xsl:attribute name="name"><xsl:value-of select="gdv:FeldID"/>
    </xsl:attribute>
    <xsl:attribute name="minOccurs">
     <xsl:choose>
      <xsl:when test="gdv:Optionalitaet = '0'">0</xsl:when>
      <xsl:otherwise>1</xsl:otherwise>
     </xsl:choose> 
    </xsl:attribute>
    <complexType>
     <sequence>
       <xsl:call-template name="PSF">
        <xsl:with-param name="feldID" select="gdv:FeldID"/>
       </xsl:call-template> 
     </sequence>
	 <attribute name="feldidentifikationKlartext" type="gdv:ET-Text030-Type" use="optional">
       <xsl:attribute name="fixed"><xsl:value-of select="gdv:FeldidentifikationKlartext"/></xsl:attribute>
	 </attribute>
	 <attribute name="wert" use="required">
      <simpleType>
 	   <xsl:choose>
	    <xsl:when test="gdv:Feldtyp = '010'">
	     <restriction base="boolean">
	      <pattern value="[01]"/>
	     </restriction> 
	    </xsl:when>
	    <xsl:when test="gdv:Feldtyp = '020'">
	     <restriction base="string">
	      <pattern>
           <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:pattern/@gdv:value"/></xsl:attribute>
	      </pattern>
	     </restriction> 
	    </xsl:when>
	    <xsl:when test="gdv:Feldtyp = '030'">
	     <restriction base="decimal">
	      <totalDigits>
           <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:totalDigits/@value"/></xsl:attribute>
	      </totalDigits>
	      <fractionDigits>
           <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:fractionDigits/@value"/></xsl:attribute>
	      </fractionDigits>
          <xsl:if test="gdv:Formatdefinition/gdv:minInclusive">
 	       <minInclusive>
            <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:minInclusive/@value"/></xsl:attribute>
	       </minInclusive>
          </xsl:if>
          <xsl:if test="gdv:Formatdefinition/gdv:minExclusive">
 	       <minExclusive>
            <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:minExclusive/@value"/></xsl:attribute>
	       </minExclusive>
          </xsl:if>
          <xsl:if test="gdv:Formatdefinition/gdv:maxInclusive">
 	       <maxInclusive>
            <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:maxInclusive/@value"/></xsl:attribute>
	       </maxInclusive>
          </xsl:if>
          <xsl:if test="gdv:Formatdefinition/gdv:maxExclusive">
 	       <maxExclusive>
            <xsl:attribute name="value"><xsl:value-of select="gdv:Formatdefinition/gdv:maxExclusive/@value"/></xsl:attribute>
	       </maxExclusive>
          </xsl:if>
	     </restriction> 
	    </xsl:when>
	    <xsl:when test="gdv:Feldtyp = '040'">
	     <restriction base="string"/>
	    </xsl:when>
	    <xsl:when test="gdv:Feldtyp = '050'">
	     <restriction base="string">
	      <xsl:for-each select="gdv:Formatdefinition/gdv:enumeration">
           <enumeration>
            <xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
	       </enumeration>
	      </xsl:for-each>
	     </restriction> 
	    </xsl:when>
	   </xsl:choose>
	  </simpleType> 
	 </attribute>
    </complexType>
   </element>
  </xsl:for-each>
 </xsl:template> 

</xsl:stylesheet>
